% Reduction 14-Apr-2020 

% use NBFSMN records to compute monthly-mean temp and sal
%   at surface and bottom at 11 sites for all available years to 2017
% and vertical-means
% and stratification

% basic initial setup
wipe;
modprelims;

% retrieve inputs
ingrps = { 'Config'; }; inputsdiary;

% initialize results arrays
nyr = length(yrs);
nstn = length(stns);
nmon = length(monst);
temp.sh = nan*ones(nstn,nyr,nmon);
temp.dp = nan*ones(nstn,nyr,nmon);
temp.bth = nan*ones(nstn,nyr,nmon);
sal = temp;
strat = nan*ones(nstn,nyr,nmon);

% loops for temp and sal
fprintf('TEMP AND SAL');
for istn = 1:nstn
    fprintf('Station %s (%d/%d)\n',stns{istn},istn,nstn);
    fils = dir([indir stns{istn} '*.mat']);
    nfil = length(fils);
    for ifil = 1:nfil
        yr = str2num(fils(ifil).name(3:6));
        fprintf('   Year %d (file %d/%d)\n',yr,ifil,nfil)
        dat = load([indir fils(ifil).name]);
        iyr = find(yrs==yr);
        for imon = 1:nmon
            fprintf('      Month %d (%d/%d)\n',monst(imon),imon,nmon)
            st = datenum(yr,monst(imon),dyst(imon));
            fn = datenum(yr,monfn(imon),dyfn(imon));
            ndy = fn-st;
            ind = find(dat.qh.dnest>=st & dat.qh.dnest<=fn);
            clear st fn;
            % temp sh
            tdat = dat.qh.sh.temp(ind);
            tdat = tdat(~isnan(tdat));
            if length(tdat)/(ndy*24*4) >= minpct/100
                temp.sh(istn,iyr,imon) = mean(tdat);
            end
            clear tdat;
            % temp dp
            tdat = dat.qh.dp.temp(ind);
            tdat = tdat(~isnan(tdat));
            if length(tdat)/(ndy*24*4) >= minpct/100
                temp.dp(istn,iyr,imon) = mean(tdat);
            end
            clear tdat;
            % temp bth
            if ~isnan(temp.sh(istn,iyr,imon))&~isnan(temp.dp(istn,iyr,imon))
                temp.bth(istn,iyr,imon) = mean([temp.sh(istn,iyr,imon)...
                    temp.dp(istn,iyr,imon)]);
            end
            % sal sh
            tdat = dat.qh.sh.sal(ind);
            tdat = tdat(~isnan(tdat));
            if length(tdat)/(ndy*24*4) >= minpct/100
                sal.sh(istn,iyr,imon) = mean(tdat);
            end
            clear tdat;
            % sal dp
            tdat = dat.qh.dp.sal(ind);
            tdat = tdat(~isnan(tdat));
            if length(tdat)/(ndy*24*4) >= minpct/100
                sal.dp(istn,iyr,imon) = mean(tdat);
            end
            clear tdat;
            % sal bth
            if ~isnan(sal.sh(istn,iyr,imon))&~isnan(sal.dp(istn,iyr,imon))
                sal.bth(istn,iyr,imon) = mean([sal.sh(istn,iyr,imon)...
                    sal.dp(istn,iyr,imon)]);
            end
            clear ind ndy;
        end
        clear dat yr iyr imon;
    end
    clear nfil fils ifil;
end
clear istn;
    
% loop for strat
fprintf('STRAT');
for istn = 1:nstn
    fprintf('Station %s (%d/%d)\n',stns{istn},istn,nstn);
    fils = dir([indirstrat stns{istn} '*.mat']);
    nfil = length(fils);
    for ifil = 1:nfil
        yr = str2num(fils(ifil).name(3:6));
        fprintf('   Year %d (file %d/%d)\n',yr,ifil,nfil)
        dat = load([indirstrat fils(ifil).name]);
        iyr = find(yrs==yr);
        for imon = 1:nmon
            fprintf('      Month %d (%d/%d)\n',monst(imon),imon,nmon)
            st = datenum(yr,monst(imon),dyst(imon));
            fn = datenum(yr,monfn(imon),dyfn(imon));
            ndy = fn-st;
            ind = find(dat.qh.dnest>=st & dat.qh.dnest<=fn);
            clear st fn;
            % strat
            tdat = dat.qh.delsig(ind);
            tdat = tdat(~isnan(tdat));
            if length(tdat)/(ndy*24*4) >= minpct/100
                strat(istn,iyr,imon) = mean(tdat);
            end
            clear tdat;
            clear ind ndy;
        end
        clear dat yr iyr imon;
    end
    clear nfil fils ifil;
end
clear istn;

eval(sprintf('save dat/monthlymeans%s temp sal strat stns yrs monst;',...
    runname));
            
% end of module
diary off;